@@ -231,3 +231,14 @@ int par_env_clean () {
         return 0;
     return 1;
 }
+
+void par_die(const char *format, ...)
+{
+    va_list ap;
+    va_start(ap, format);
+    vfprintf(stderr, format, ap);
+    va_end(ap);
+    
+    exit(255);
+}
+
